<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_supprimer_petition' => 'Poista vetoomus',

	// F
	'form_pet_adresse_site' => 'Sivustosi URL-osoite', # MODIF
	'form_pet_aucune_signature' => 'Mikään allekirjoitus ei sovi tähän koodiin...', # MODIF
	'form_pet_confirmation' => 'Vahvista allekirjoituksesi:',
	'form_pet_deja_signe' => 'Olet jo allekirjoittanut tämän tekstin.',
	'form_pet_nom_site2' => 'Nettisivustosi nimi', # MODIF
	'form_pet_site_deja_enregistre' => 'Tämä sivusto on jo rekisteröity',
	'form_pet_url_invalide' => 'Antamasi URL-osoite ei ole kelvollinen',
	'form_pet_votre_email' => 'Sähköpostiosoitteesi',
	'form_pet_votre_nom' => 'Nimesi tai nimimerkkisi', # MODIF
	'form_pet_votre_site' => 'Voit lisätä seuraavaan, mahdollisen nettisivustosi',

	// I
	'info_adresse_email' => 'SÄHKÖPOSTI-OSOITE:',
	'info_site_web' => 'NETTISIVU:'
);

?>
